Index: src/Analysis/analysis_correlation.hpp
===================================================================
--- src/Analysis/analysis_correlation.hpp	(revision 6f0841afb57916ffe2e660310f1ff1062d59144a)
+++ src/Analysis/analysis_correlation.hpp	(revision 6bd7e05ae215210d42ef6cb22768847bee2ce5da)
@@ -40,5 +40,5 @@
 class Formula;
 class element;
-class LinkedCell;
+class LinkedCell_deprecated;
 class Tesselation;
 class Vector;
@@ -67,8 +67,8 @@
 PairCorrelationMap *PairCorrelation(std::vector<molecule *> &molecules, const std::vector<const element *> &elements);
 CorrelationToPointMap *CorrelationToPoint(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const Vector *point );
-CorrelationToSurfaceMap *CorrelationToSurface(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const Tesselation * const Surface, const LinkedCell *LC );
+CorrelationToSurfaceMap *CorrelationToSurface(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const Tesselation * const Surface, const LinkedCell_deprecated *LC );
 PairCorrelationMap *PeriodicPairCorrelation(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const int ranges[NDIM] );
 CorrelationToPointMap *PeriodicCorrelationToPoint(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const Vector *point, const int ranges[NDIM] );
-CorrelationToSurfaceMap *PeriodicCorrelationToSurface(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const Tesselation * const Surface, const LinkedCell *LC, const int ranges[NDIM] );
+CorrelationToSurfaceMap *PeriodicCorrelationToSurface(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const Tesselation * const Surface, const LinkedCell_deprecated *LC, const int ranges[NDIM] );
 int GetBin ( const double value, const double BinWidth, const double BinStart );
 void OutputCorrelation_Header( ofstream * const file );
Index: src/Analysis/unittests/AnalysisCorrelationToSurfaceUnitTest.cpp
===================================================================
--- src/Analysis/unittests/AnalysisCorrelationToSurfaceUnitTest.cpp	(revision 6f0841afb57916ffe2e660310f1ff1062d59144a)
+++ src/Analysis/unittests/AnalysisCorrelationToSurfaceUnitTest.cpp	(revision 6bd7e05ae215210d42ef6cb22768847bee2ce5da)
@@ -102,6 +102,6 @@
   Surface = new Tesselation;
   PointCloudAdaptor<molecule> cloud(TestSurfaceMolecule, TestSurfaceMolecule->name);
-  LC = new LinkedCell(cloud, 5.);
-  FindNonConvexBorder(TestSurfaceMolecule, Surface, (const LinkedCell *&)LC, 2.5, NULL);
+  LC = new LinkedCell_deprecated(cloud, 5.);
+  FindNonConvexBorder(TestSurfaceMolecule, Surface, (const LinkedCell_deprecated *&)LC, 2.5, NULL);
 
   // add outer atoms
Index: src/Analysis/unittests/AnalysisCorrelationToSurfaceUnitTest.hpp
===================================================================
--- src/Analysis/unittests/AnalysisCorrelationToSurfaceUnitTest.hpp	(revision 6f0841afb57916ffe2e660310f1ff1062d59144a)
+++ src/Analysis/unittests/AnalysisCorrelationToSurfaceUnitTest.hpp	(revision 6bd7e05ae215210d42ef6cb22768847bee2ce5da)
@@ -18,5 +18,5 @@
 
 class element;
-class LinkedCell;
+class LinkedCell_deprecated;
 class molecule;
 class MoleculeListClass;
@@ -58,5 +58,5 @@
       BinPairMap *binmap;
       Tesselation *Surface;
-      LinkedCell *LC;
+      LinkedCell_deprecated *LC;
 };
 

Index: src/Analysis/analysis_correlation.cpp
===================================================================
--- src/Analysis/analysis_correlation.cpp	(revision 6f0841afb57916ffe2e660310f1ff1062d59144a)
+++ src/Analysis/analysis_correlation.cpp	(revision 6bd7e05ae215210d42ef6cb22768847bee2ce5da)
@@ -531,8 +531,8 @@
  * \param &elements vector of elements to correlate to surface
  * \param *Surface pointer to Tesselation class surface
  * \param *LC LinkedCell structure to quickly find neighbouring atoms
  * \return Map of doubles with values as pairs of atom and the BoundaryTriangleSet that's closest
  */
-CorrelationToSurfaceMap *CorrelationToSurface(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const Tesselation * const Surface, const LinkedCell *LC )
+CorrelationToSurfaceMap *CorrelationToSurface(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const Tesselation * const Surface, const LinkedCell_deprecated *LC )
 {
   Info FunctionInfo(__func__);
@@ -584,9 +584,9 @@
  * \param &elements vector of elements to correlate to surface
  * \param *Surface pointer to Tesselation class surface
  * \param *LC LinkedCell structure to quickly find neighbouring atoms
  * \param ranges[NDIM] interval boundaries for the periodic images to scan also
  * \return Map of doubles with values as pairs of atom and the BoundaryTriangleSet that's closest
  */
-CorrelationToSurfaceMap *PeriodicCorrelationToSurface(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const Tesselation * const Surface, const LinkedCell *LC, const int ranges[NDIM] )
+CorrelationToSurfaceMap *PeriodicCorrelationToSurface(std::vector<molecule *> &molecules, const std::vector<const element *> &elements, const Tesselation * const Surface, const LinkedCell_deprecated *LC, const int ranges[NDIM] )
 {
   Info FunctionInfo(__func__);
@@ -531,8 +531,8 @@
  * \param &elements vector of elements to correlate to surface
  * \param *Surface pointer to Tesselation class surface
- * \param *LC LinkedCell structure to quickly find neighbouring atoms
+ * \param *LC LinkedCell_deprecated structure to quickly find neighbouring atoms
  * \return Map of doubles with values as pairs of atom and the BoundaryTriangleSet that's closest
  */
@@ -584,9 +584,9 @@
  * \param &elements vector of elements to correlate to surface
  * \param *Surface pointer to Tesselation class surface
- * \param *LC LinkedCell structure to quickly find neighbouring atoms
+ * \param *LC LinkedCell_deprecated structure to quickly find neighbouring atoms
  * \param ranges[NDIM] interval boundaries for the periodic images to scan also
  * \return Map of doubles with values as pairs of atom and the BoundaryTriangleSet that's closest